pub struct StartCopyJobInput {
pub destination_backup_vault_arn: String,
pub iam_role_arn: String,
pub idempotency_token: Option<String>,
pub lifecycle: Option<Lifecycle>,
pub recovery_point_arn: String,
pub source_backup_vault_name: String,
}Fields
destination_backup_vault_arn: StringAn Amazon Resource Name (ARN) that uniquely identifies a destination backup vault to copy to; for example, arn:aws:backup:us-east-1:123456789012:vault:aBackupVault.
iam_role_arn: StringSpecifies the IAM role ARN used to copy the target recovery point; for example, arn:aws:iam::123456789012:role/S3Access.
idempotency_token: Option<String>A customer chosen string that can be used to distinguish between calls to StartCopyJob.
lifecycle: Option<Lifecycle>recovery_point_arn: StringAn ARN that uniquely identifies a recovery point to use for the copy job; for example, arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
source_backup_vault_name: StringThe name of a logical source container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens.